@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef DEVICE_H
@@ -23,8 +23,6 @@
 
 #include <QObject>
 #include <QString>
-#include <QVector>
-#include <QSet>
 #include <QHostAddress>
 
 #include "networkpacket.h"
@@ -41,7 +39,7 @@ class KDECONNECTCORE_EXPORT Device
     Q_PROPERTY(QString type READ type CONSTANT)
     Q_PROPERTY(QString name READ name NOTIFY nameChanged)
     Q_PROPERTY(QString iconName READ iconName CONSTANT)
-    Q_PROPERTY(QString statusIconName READ statusIconName)
+    Q_PROPERTY(QString statusIconName READ statusIconName NOTIFY statusIconNameChanged)
     Q_PROPERTY(bool isReachable READ isReachable NOTIFY reachableChanged)
     Q_PROPERTY(bool isTrusted READ isTrusted NOTIFY trustedChanged)
     Q_PROPERTY(QStringList supportedPlugins READ supportedPlugins NOTIFY pluginsChanged)
@@ -55,6 +53,7 @@ public:
         Laptop,
         Phone,
         Tablet,
+        Tv,
     };
 
     /**
@@ -73,10 +72,10 @@ public:
 
     ~Device() override;
 
-    QString id() const { return m_deviceId; }
-    QString name() const { return m_deviceName; }
-    QString dbusPath() const { return "/modules/kdeconnect/devices/"+id(); }
-    QString type() const { return type2str(m_deviceType); }
+    QString id() const;
+    QString name() const;
+    QString dbusPath() const { return QStringLiteral("/modules/kdeconnect/devices/") + id(); }
+    QString type() const;
     QString iconName() const;
     QString statusIconName() const;
     Q_SCRIPTABLE QString encryptionInfo() const;
@@ -88,7 +87,7 @@ public:
     Q_SCRIPTABLE bool isTrusted() const;
 
     Q_SCRIPTABLE QStringList availableLinks() const;
-    bool isReachable() const { return !m_deviceLinks.isEmpty(); }
+    virtual bool isReachable() const;
 
     Q_SCRIPTABLE QStringList loadedPlugins() const;
     Q_SCRIPTABLE bool hasPlugin(const QString& name) const;
@@ -101,8 +100,8 @@ public:
 
     void cleanUnneededLinks();
 
-    int protocolVersion() { return m_protocolVersion; }
-    QStringList supportedPlugins() const { return m_supportedPlugins.toList(); }
+    int protocolVersion();
+    QStringList supportedPlugins() const;
 
     QHostAddress getLocalIpAddress() const;
 
@@ -121,6 +120,7 @@ public Q_SLOTS:
     Q_SCRIPTABLE void rejectPairing();
     Q_SCRIPTABLE bool hasPairingRequests() const;
 
+    Q_SCRIPTABLE QString pluginIconName(const QString& pluginName);
 private Q_SLOTS:
     void privateReceivedPacket(const NetworkPacket& np);
     void linkDestroyed(QObject* o);
@@ -134,6 +134,7 @@ Q_SIGNALS:
     Q_SCRIPTABLE void trustedChanged(bool trusted);
     Q_SCRIPTABLE void pairingError(const QString& error);
     Q_SCRIPTABLE void nameChanged(const QString& name);
+    Q_SCRIPTABLE void statusIconNameChanged();
 
     Q_SCRIPTABLE void hasPairingRequestsChanged(bool hasPairingRequests);
 
@@ -144,19 +145,9 @@ private: //Methods
     void setName(const QString& name);
     QString iconForStatus(bool reachable, bool paired) const;
 
-private: //Fields (TODO: dPointer!)
-    const QString m_deviceId;
-    QString m_deviceName;
-    DeviceType m_deviceType;
-    int m_protocolVersion;
-
-    QVector<DeviceLink*> m_deviceLinks;
-    QHash<QString, KdeConnectPlugin*> m_plugins;
-
-    //Capabilities stuff
-    QMultiMap<QString, KdeConnectPlugin*> m_pluginsByIncomingCapability;
-    QSet<QString> m_supportedPlugins;
-    QSet<PairingHandler*> m_pairRequests;
+private:
+    class DevicePrivate;
+    DevicePrivate *d;
 };
 
 Q_DECLARE_METATYPE(Device*)
