@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "sftpplugin.h"
@@ -32,18 +32,16 @@
 #include <KPluginFactory>
 
 #include "mounter.h"
-#include "sftp_debug.h"
+#include "plugin_sftp_debug.h"
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_sftp.json", registerPlugin< SftpPlugin >(); )
-
-Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_SFTP, "kdeconnect.plugin.sftp")
+K_PLUGIN_CLASS_WITH_JSON(SftpPlugin, "kdeconnect_sftp.json")
 
 static const QSet<QString> fields_c = QSet<QString>() << QStringLiteral("ip") << QStringLiteral("port") << QStringLiteral("user") << QStringLiteral("port") << QStringLiteral("path");
 
 struct SftpPlugin::Pimpl
 {
     Pimpl() : m_mounter(nullptr) {}
-  
+
     //Add KIO entry to Dolphin's Places
     KFilePlacesModel  m_placesModel;
     Mounter* m_mounter;
@@ -52,7 +50,7 @@ struct SftpPlugin::Pimpl
 SftpPlugin::SftpPlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
     , d(new Pimpl())
-{ 
+{
     deviceId = device()->id();
     addToDolphin();
     qCDebug(KDECONNECT_PLUGIN_SFTP) << "Created device:" << device()->name();
@@ -60,22 +58,22 @@ SftpPlugin::SftpPlugin(QObject* parent, const QVariantList& args)
 
 SftpPlugin::~SftpPlugin()
 {
-    QDBusConnection::sessionBus().unregisterObject(dbusPath(), QDBusConnection::UnregisterTree);
-    removeFromDolphin();    
+    removeFromDolphin();
     unmount();
 }
 
 void SftpPlugin::addToDolphin()
 {
     removeFromDolphin();
-    QUrl kioUrl("kdeconnect://"+deviceId+"/");
+
+    QUrl kioUrl(QStringLiteral("kdeconnect://") + deviceId + QStringLiteral("/"));
     d->m_placesModel.addPlace(device()->name(), kioUrl, QStringLiteral("kdeconnect"));
     qCDebug(KDECONNECT_PLUGIN_SFTP) << "add to dolphin";
 }
 
 void SftpPlugin::removeFromDolphin()
 {
-    QUrl kioUrl("kdeconnect://"+deviceId+"/");
+    QUrl kioUrl(QStringLiteral("kdeconnect://") + deviceId + QStringLiteral("/"));
     QModelIndex index = d->m_placesModel.closestItem(kioUrl);
     while (index.row() != -1) {
         d->m_placesModel.removePlace(index);
@@ -116,23 +114,32 @@ bool SftpPlugin::isMounted() const
     return d->m_mounter && d->m_mounter->isMounted();
 }
 
+QString SftpPlugin::getMountError()
+{
+    if (!mountError.isEmpty()) {
+        return mountError;
+    }
+    return QString();
+}
+
+
 bool SftpPlugin::startBrowsing()
 {
     if (mountAndWait()) {
         //return new KRun(QUrl::fromLocalFile(mountPoint()), 0);
-        return new KRun(QUrl("kdeconnect://"+deviceId), nullptr);
+        return new KRun(QUrl(QStringLiteral("kdeconnect://") + deviceId), nullptr);
     }
     return false;
 }
 
-bool SftpPlugin::receivePackage(const NetworkPackage& np)
+bool SftpPlugin::receivePacket(const NetworkPacket& np)
 {
-    if (!(fields_c - np.body().keys().toSet()).isEmpty()) {
-        // package is invalid
+    if (!(fields_c - np.body().keys().toSet()).isEmpty() && !np.has(QStringLiteral("errorMessage"))) {
+        // packet is invalid
         return false;
     }
-    
-    Q_EMIT packageReceived(np);
+
+    Q_EMIT packetReceived(np);
 
     remoteDirectories.clear();
     if (np.has(QStringLiteral("multiPaths"))) {
@@ -144,9 +151,8 @@ bool SftpPlugin::receivePackage(const NetworkPackage& np)
         }
     } else {
         remoteDirectories.insert(mountPoint(), i18n("All files"));
-        remoteDirectories.insert(mountPoint() + "/DCIM/Camera", i18n("Camera pictures"));
+        remoteDirectories.insert(mountPoint() + QStringLiteral("/DCIM/Camera"), i18n("Camera pictures"));
     }
-
     return true;
 }
 
@@ -171,12 +177,13 @@ void SftpPlugin::onUnmounted()
     qCDebug(KDECONNECT_PLUGIN_SFTP) << device()->name() << "Remote filesystem unmounted";
 
     unmount();
-    
+
     Q_EMIT unmounted();
 }
 
 void SftpPlugin::onFailed(const QString& message)
 {
+    mountError = message;
     KNotification::event(KNotification::Error, device()->name(), message);
 
     unmount();
